@@ -26,6 +26,15 @@ if [ ! -d "$basepath/systemd_el" ]; then
         cp -r "$basepath/base" "$basepath/systemd_el"
         DESTDIR="$basepath/systemd_el" bash install.sh systemd_redhat
 fi
+if [ ! -d "$basepath/old_el" ]; then
+        cp -r "$basepath/base" "$basepath/old_el"
+        DESTDIR="$basepath/old_el" bash install.sh sysv_init_redhat
+fi
+if [ ! -d "$basepath/old_sles" ]; then
+        cp -r "$basepath/base" "$basepath/old_sles"
+        DESTDIR="$basepath/old_sles" bash install.sh sysv_init_suse
+fi
+
 
 # things are only different if we have docs, deb docs get
 # installed in an unversioned folder but rpm docs get installed
@@ -37,12 +46,28 @@ if [ -d ext/docs ]; then
                         cp -r "$basepath/base_deb" "$basepath/systemd_deb"
                         DESTDIR="$basepath/systemd_deb" bash install.sh systemd_deb
                 fi
+                if [ ! -d "$basepath/systemd_notasksmax_deb" ]; then
+                        cp -r "$basepath/base_deb" "$basepath/systemd_notasksmax_deb"
+                        DESTDIR="$basepath/systemd_notasksmax_deb" USE_TASKSMAX=false bash install.sh systemd_deb
+                fi
+                if [ ! -d "$basepath/sysvinit_deb" ]; then
+                        cp -r "$basepath/base_deb" "$basepath/sysvinit_deb"
+                        DESTDIR="$basepath/sysvinit_deb" bash install.sh sysv_init_deb
+                fi
         fi
 else
         if [ ! -d "$basepath/systemd_deb" ]; then
                 cp -r "$basepath/base" "$basepath/systemd_deb"
                 DESTDIR="$basepath/systemd_deb" bash install.sh systemd_deb
         fi
+        if [ ! -d "$basepath/systemd_notasksmax_deb" ]; then
+                cp -r "$basepath/base" "$basepath/systemd_notasksmax_deb"
+                DESTDIR="$basepath/systemd_notasksmax_deb" USE_TASKSMAX=false bash install.sh systemd_deb
+        fi
+        if [ ! -d "$basepath/sysvinit_deb" ]; then
+                cp -r "$basepath/base" "$basepath/sysvinit_deb"
+                DESTDIR="$basepath/sysvinit_deb" bash install.sh sysv_init_deb
+        fi
 fi
 
 os=$build_os
@@ -56,11 +81,33 @@ case $os in
         # there's no differences in packaging for deb vs ubuntu
         # if that changes we'll need to fix this
         debian|ubuntu)
-                dir="$basepath/systemd_deb"
+                if [ "$os_dist" = 'trusty' ]; then
+                        dir="$basepath/sysvinit_deb"
+                elif [ "$os_dist" = 'jessie' ]; then
+                        # the version of systemd that ships with jessie doesn't
+                        # support TasksMax
+                        dir="$basepath/systemd_notasksmax_deb"
+                else
+                        dir="$basepath/systemd_deb"
+                fi
                 ;;
-        amazon|el|redhatfips|sles)
+        el|redhatfips)
+                if [ "$os_version" -gt '6' ]; then
+                        dir="$basepath/systemd_el"
+                else
+                        dir="$basepath/old_el"
+                fi
+                ;;
+        amazon)
                 dir="$basepath/systemd_el"
                 ;;
+        sles)
+                if [ "$os_version" -gt '11' ]; then
+                        dir="$basepath/systemd_el"
+                else
+                        dir="$basepath/old_sles"
+                fi
+                ;;
         *)
                 echo "I have no idea what I'm doing with $os, teach me?" >&2
                 exit 1
@@ -68,18 +115,18 @@ case $os in
 esac
 
 # bash will eat your spaces, so let's array. see http://mywiki.wooledge.org/BashFAQ/050 for more fun.
-params=("--user" "puppetdb" "--group" "puppetdb" "--chdir" "$dir" "--realname" "puppetdb" "--operating-system" "$os" "--name" "openvoxdb" "--package-version" "8.10.0" "--release" "1" "--platform-version" "8")
+params=("--user" "puppetdb" "--group" "puppetdb" "--chdir" "$dir" "--realname" "puppetdb" "--operating-system" "$os" "--name" "openvoxdb" "--package-version" "8.11.0" "--release" "1" "--platform-version" "8")
 if [ -n "$os_version" ]; then params+=("--os-version" "$os_version"); fi
 if [ -n "$os_dist" ]; then params+=("--dist" "$os_dist"); fi
 
-params+=('--description' "$(printf "Vox Pupuli puppetdb\nContains: OpenVox-integrated catalog and fact storage (puppetlabs/puppetdb 8.10.0,org.bouncycastle/bcpkix-jdk18on 1.78.1,org.clojure/clojure 1.11.2,puppetlabs/puppetdb 8.10.0)")")
+params+=('--description' "$(printf "Vox Pupuli puppetdb\nContains: OpenVox-integrated catalog and fact storage (puppetlabs/puppetdb 8.11.0,org.bouncycastle/bcpkix-jdk18on 1.78.1,org.clojure/clojure 1.11.2,puppetlabs/puppetdb 8.11.0)")")
 
 DESTDIR="$basepath/termini" bash install.sh termini
 params+=('--build-termini')
 params+=('--termini-chdir' "$basepath/termini")
 termini_description='Termini for puppetdb\nContains terminus for:'
 
-termini_description+='puppetdb (version 8.10.0)'
+termini_description+='puppetdb (version 8.11.0)'
 
 params+=('--termini-description' "$(printf "$termini_description")")
 
@@ -89,6 +136,7 @@ params+=('--replaces' "'puppetdb',''")
 
 
 
+
 if [[ "$os" = 'el' || "$os" = 'sles' || "$os" = 'fedora' || "$os" = 'redhatfips' || "$os" = 'amazon' ]]; then
         # pull in rpm dependencies
                         params+=("--additional-dependency")
